$ifndef _HID_DESC_INC_
$define _HID_DESC_INC_
'
' USB descriptors for Jan Axelson's USB Demo
'
$define cVID                    0x0925      ' Vendor ID (Keep to 0x format for Hex value)
$define cPID                    0x1234      ' Product ID (Keep to 0x format for Hex value)
$define cUSB_EP0_BUFF_SIZE      8           ' 8, 16, 32, or 64
$define cUSB_MAX_NUM_INT        1
$define cUSB_MAX_EP_NUMBER      1
$define cUSB_NUM_CONFIGS        1
$define cUSB_NUM_INTERFACES     1
$define cUSB_MAX_POWER          100         ' Maximum power consumption (in MilliAmps)
$define cUSB_POLLING_INTERVAL   10          ' Polling interval (in MilliSeconds)

'$define cUSE_SELF_POWER
'$define cUSE_USB_BUS_SENSE_IO

$ifdef cUSE_USB_BUS_SENSE_IO
    Symbol USB_BUS_SENSE_PIN = PORTA.0
$endif

$define cUSB_POLLING

' HID
' Endpoints Allocation
$define cHID_INTF_ID         0
$define cHID_EP              1
$define cHID_INT_OUT_EP_SIZE 8
$define cHID_INT_IN_EP_SIZE  8
$define cHID_NUM_OF_DSC      1

    Symbol cUSB_BUFFER_OUT_SIZE = cHID_INT_OUT_EP_SIZE
    Symbol cUSB_BUFFER_IN_SIZE  = cHID_INT_IN_EP_SIZE

    GoTo _DescriptorMain_               ' Jump over the USB code
    Include "USB_HID.inc"               ' Include the HID class code

'--------------------------------------------------------------------------------------------------------------------
' This table is polled by the host immediately after USB Reset has been released.
' This table defines the maximum packet size EP0 can take.
' See section 9.6.1 of the Rev 1.0 USB specification.
' These fields are application dependent. Modify these to meet your specifications.
'
Desc_DeviceDescriptor:
    Dt (Desc_EndDeviceDescriptor - Desc_DeviceDescriptor) / 2    ' Size of this descriptor (in bytes)
    Dt cUSB_DESCRIPTOR_DEVICE           ' Device descriptor type
    Dt 0x10, 0x01                       ' USB Spec Release Number in BCD format - 1.10 (low byte, high byte)
    Dt 0x00                             ' Class Code
    Dt 0x00                             ' Subclass code
    Dt 0x00                             ' Protocol code
    Dt cUSB_EP0_BUFF_SIZE               ' Max packet size for EP0
    Dt Low(cVID), High(cVID)            ' Vendor ID - 0x0925 is LakeView Research ID (low byte)
    Dt Low(cPID), High(cPID)            ' Product ID: Jan Axelson demo (low byte)
    Dt 0x01                             ' Device release number in BCD format (low byte)
    Dt 0x00                             ' (high byte)
    Dt 0x01                             ' Manufacturer string index
    Dt 0x02                             ' Product string index
    Dt 0x00                             ' Device serial number string index
    Dt cUSB_NUM_CONFIGS                 ' Number of possible configurations
Desc_EndDeviceDescriptor:

'--------------------------------------------------------------------------------------------------------------------
' This table is retrieved by the host after the address has been set.
' This table defines the configurations available for the device.
' See section 9.6.2 of the Rev 1.0 USB specification (page 184).
' These fields are application DEPENDENT.
' Modify these to meet your specifications.
'
' Configuration Descriptor
'
Desc_Config1:
    Dt (Desc_Interface1 - Desc_Config1) / 2         ' Size of this descriptor (in bytes)
    Dt cUSB_DESCRIPTOR_CONFIGURATION                ' Configuration descriptor type

Desc_Config1Len:
    Dt Low((Desc_EndConfig1 - Desc_Config1) / 2),High((Desc_EndConfig1 - Desc_Config1) / 2) ' Total length of data for this cfg
    Dt cUSB_NUM_INTERFACES                          ' Number of interfaces in this cfg
    Dt 0x01                                         ' Index value of this configuration
    Dt 0x00                                         ' Configuration string index
    Dt _cDEFAULT | _cSELF                           ' Attributes
    Dt (cUSB_MAX_POWER / 2)                         ' Max power consumption (in mA)
'
' Interface descriptor
'
Desc_Interface1:
    Dt (Desc_HIDDescriptor1 - Desc_Interface1) / 2  ' Size of this descriptor (in bytes)
    Dt cUSB_DESCRIPTOR_INTERFACE                    ' Interface descriptor type
    Dt 0x00                                         ' Interface Number
    Dt 0x00                                         ' Alternate Setting Number
    Dt 0x02                                         ' Number of endpoints in this intf
    Dt cHID_INTF                                    ' Class code
    Dt 0x00                                         ' Subclass code
    Dt 0x00                                         ' Protocol code
    Dt 0x00                                         ' Interface string index
'
' HID class-specific descriptor
'
Desc_HIDDescriptor1:
    Dt (Desc_Endpoint1Out - Desc_HIDDescriptor1) / 2' Size of this descriptor (in bytes)
    Dt cDSC_HID                                     ' HID descriptor type
    Dt 0x11, 0x01                                   ' HID Spec Release Number in BCD format - 1.11 (low byte,high byte)
    Dt 0x00                                         ' Country Code (0x00 for Not supported)
    Dt cHID_NUM_OF_DSC                              ' Number of class descriptors
    Dt cDSC_RPT                                     ' Report descriptor type (HID)

Desc_ReportDescriptor1Len:
    Dt Low((Desc_EndReportDescriptor1 - Desc_ReportDescriptor1) / 2),High((Desc_EndReportDescriptor1 - Desc_ReportDescriptor1) / 2)
'
' Enpoint descriptor (OUT)
'
Desc_Endpoint1Out:
    Dt (Desc_Endpoint1In - Desc_Endpoint1Out) / 2   ' Size of this descriptor (in bytes)
    Dt cUSB_DESCRIPTOR_ENDPOINT                     ' EndPoint descriptor type
    Dt cHID_EP | _cEP_OUT                           ' EndPoint Address
    Dt _cINT                                        ' Attributes
    Dt Low(cHID_INT_OUT_EP_SIZE),0x00               ' Size of the EndPoint buffer (in bytes) (low byte, high byte)
    Dt cUSB_POLLING_INTERVAL                        ' Polling interval (in ms)
'
' Endpoint descriptor (IN)
'
Desc_Endpoint1In:
    Dt (Desc_EndConfig1 - Desc_Endpoint1In) / 2     ' Size of this descriptor (in bytes)
    Dt cUSB_DESCRIPTOR_ENDPOINT                     ' EndPoint descriptor type
    Dt cHID_EP | _cEP_IN                            ' EndPoint Address
    Dt _cINT                                        ' Attributes
    Dt Low(cHID_INT_IN_EP_SIZE),0x00                ' Size of the EndPoint buffer (in bytes) (low byte,high byte)
    Dt cUSB_POLLING_INTERVAL                        ' Polling interval (in ms)
Desc_EndConfig1:

Desc_ReportDescriptor1:
    Dt 0x06, 0xA0, 0xFF     ' Usage page (Vendor Defined)
    Dt 0x09, 0x01           ' Usage (Vendor Defined)
    Dt 0xA1, 0x01           ' Collection (application)

    Dt 0x09, 0x02           ' Usage (Vendor Defined)
    Dt 0xA1, 0x00           ' Collection (linked)
    Dt 0x06, 0xA1, 0xFF     ' Usage page (buttons)

    Dt 0x09, 0x03           ' Usage vendor defined
    Dt 0x09, 0x04           ' Usage vendor defined
    Dt 0x15, 0x80           ' Logical minimum ( - 128)
    Dt 0x25, 0x7F           ' Logical maximum (127)
    Dt 0x35, 0x00           ' Physical Minimum (0)
    Dt 0x45, 0xFF           ' Physical Maximum (255)
    Dt 0x75, 0x08           ' Report size (8-bits)
    Dt 0x95, 0x02           ' Report count (2 fields)
    Dt 0x81, 0x02           ' Input (Data, Variable, Absolute)

    Dt 0x09, 0x05           ' Usage (Vendor Defined)
    Dt 0x09, 0x06           ' Useage (Vendor Defined)
    Dt 0x15, 0x80           ' Logical minimum ( - 128)
    Dt 0x25, 0x7F           ' Logical maximum (127)
    Dt 0x35, 0x00           ' Physical Minimum (0)
    Dt 0x45, 0xFF           ' Physical Maximum (255)
    Dt 0x75, 0x08           ' Report size (8-bits)
    Dt 0x95, 0x02           ' Report Count (2 fields)
    Dt 0x91, 0x02           ' Output (Data, Variable, Absolute)

    Dt 0xC0, 0xC0           ' End collection

Desc_EndReportDescriptor1:
'
' Configuration pointer table
Desc_USB_CD_Ptr:
Desc_Configs:
    CData As DWord Desc_Config1
'
' String pointer table
Desc_USB_SD_Ptr:
Desc_Strings:
    CData As DWord Desc_String0, Desc_String1, Desc_String2
'
' Language code string descriptor
'
Desc_String0:-
    dt (Desc_String1 - Desc_String0) / 2            ' Size of this descriptor (in bytes)
    dt cUSB_DESCRIPTOR_STRING                       ' String descriptor type
    dt 0x09, 0x04                                   ' Language ID as defined by MS - 0x0409
'
' Manufacturer string descriptor
'
Desc_String1:-
    dt (Desc_String2 - Desc_String1) / 2            ' Size of this descriptor (in bytes)
    dt cUSB_DESCRIPTOR_STRING                       ' String descriptor type
    CData As Dword "Proton"
'
' Product string descriptor
'
Desc_String2:-
    dt (_DescriptorMain_ - Desc_String2) / 2  ' Size of this descriptor (in bytes)
    dt cUSB_DESCRIPTOR_STRING                       ' String descriptor type
    CData As Dword "PIC18 JA Demo"

_DescriptorMain_:

$endif  ' _HID_DESC_INC_
