$ifndef _MOUSE_DESC_INC_
$define _MOUSE_DESC_INC_
'
' USB descriptors for a HID mouse device
'
$define cVID                    0x04D8    ' Vendor ID (Keep to 0x format for Hex value)
$define cPID                    0x0000    ' Product ID (Keep to 0x format for Hex value)
$define cUSB_EP0_BUFF_SIZE      8         ' 8, 16, 32, or 64
$define cUSB_MAX_NUM_INT        1
$define cUSB_MAX_EP_NUMBER      1
$define cUSB_NUM_CONFIGS        1
$define cUSB_NUM_INTERFACES     1
$define cUSB_MAX_POWER          100       ' Maximum power consumption (in MilliAmps)
$define cUSB_POLLING_INTERVAL   10        ' Polling interval (in MilliSeconds)

'$define cUSE_SELF_POWER
'$define cUSE_USB_BUS_SENSE_IO

$ifdef cUSE_USB_BUS_SENSE_IO
    Symbol USB_BUS_SENSE_PIN = PORTA.0
$endif

$define cUSB_POLLING

' HID
' Endpoints Allocation
$define cHID_INTF_ID         0
$define cHID_EP              1
$define cHID_INT_OUT_EP_SIZE 3
$define cHID_INT_IN_EP_SIZE  3
$define cHID_NUM_OF_DSC      1

    Symbol cUSB_BUFFER_OUT_SIZE = cHID_INT_OUT_EP_SIZE
    Symbol cUSB_BUFFER_IN_SIZE  = cHID_INT_IN_EP_SIZE

    GoTo _DescriptorMain_                       ' Jump over the USB code
    Include "USB_HID.inc"                       ' Include the HID class code
' -----------------------------------------------------------------------------------------------------
' This table is polled by the host immediately after USB Reset has been released.
' It defines the maximum packet size EP0 can take.
' See section 9.6.1 of the Rev 1.0 USB specification.
' These fields are application dependent. Modify these to meet your specifications.
'
Desc_DeviceDescriptor:
    Dt (Desc_EndDeviceDescriptor - Desc_DeviceDescriptor) / 2    ' Size of this descriptor (in bytes)
    Dt cUSB_DESCRIPTOR_DEVICE                   ' Device descriptor type
    Dt 0x10, 0x01                               ' USB Spec Release Number in BCD format - 1.10 (low byte, high byte)
    Dt 0x00                                     ' Class Code
    Dt 0x00                                     ' Subclass code
    Dt 0x00                                     ' Protocol code
    Dt cUSB_EP0_BUFF_SIZE                       ' Max packet size for EP0
    Dt Low(cVID), High(cVID)                    ' Vendor ID - 0x04D8 is Microchip Vendor ID (low byte, high byte)
    Dt Low(cPID), High(cPID)                    ' Product ID: Mouse in a circle fw demo (low byte, high byte)
    Dt 0x03, 0x00                               ' Device release number in BCD format (low byte, high byte)
    Dt 0x01                                     ' Manufacturer string index
    Dt 0x02                                     ' Product string index
    Dt 0x00                                     ' Device serial number string index
    Dt cUSB_NUM_CONFIGS                         ' Number of possible configurations
Desc_EndDeviceDescriptor:

' -----------------------------------------------------------------------------------------------------
' This table is retrieved by the host after the address has been set.
' It defines the configurations available for the device.
' See section 9.6.2 of the Rev 1.0 USB specification (page 184).
' These fields are application dependent.
' Modify these to meet your specifications.
'
' Configuration Descriptor
'
Desc_Config1:
    Dt (Desc_Interface1 - Desc_Config1) / 2         ' Size of this descriptor (in bytes)
    Dt cUSB_DESCRIPTOR_CONFIGURATION                ' Configuration descriptor type

Desc_Config1Len:
    Dt (Desc_EndConfig1 - Desc_Config1) / 2, 0x00   ' Total length of data for this cfg
    Dt cUSB_NUM_INTERFACES                          ' Number of interfaces in this cfg
    Dt 0x01                                         ' Index value of this configuration
    Dt 0x00                                         ' Configuration string index
    Dt _cDEFAULT | _cSELF                           ' Attributes
    Dt (cUSB_MAX_POWER / 2)                         ' Max power consumption (in mA)

Desc_Interface1:
    Dt (Desc_HIDDescriptor1 - Desc_Interface1) / 2  ' Size of this descriptor (in bytes)
    Dt cUSB_DESCRIPTOR_INTERFACE                    ' Interface descriptor type
    Dt 0x00                                         ' Interface Number
    Dt 0x00                                         ' Alternate Setting Number
    Dt 0x01                                         ' Number of endpoints in this intf
    Dt cHID_INTF                                    ' Class code
    Dt cBOOT_INTF_SUBCLASS                          ' Subclass code
    Dt cHID_PROTOCOL_MOUSE                          ' Protocol code
    Dt 0x00                                         ' Interface string index

Desc_HIDDescriptor1:
    Dt (Desc_Endpoint1 - Desc_HIDDescriptor1) / 2   ' Size of this descriptor (in bytes)
    Dt cDSC_HID                                     ' HID descriptor type
    Dt 0x11, 0x01                                   ' HID Spec Release Number in BCD format - 1.11 (low byte,high byte)
    Dt 0x00                                         ' Country Code (0x00 for Not supported)
    Dt cHID_NUM_OF_DSC                              ' Number of class descriptors
    Dt cDSC_RPT                                     ' Report descriptor type (HID)

Desc_ReportDescriptor1Len:
    Dt Low((Desc_EndReportDescriptor1 - Desc_ReportDescriptor1) / 2),High((Desc_EndReportDescriptor1 - Desc_ReportDescriptor1) / 2)

Desc_Endpoint1:
    Dt (Desc_EndConfig1 - Desc_Endpoint1) / 2       ' Size of this descriptor (in bytes)
    Dt cUSB_DESCRIPTOR_ENDPOINT                     ' EndPoint descriptor type
    Dt cHID_EP | _cEP_IN                            ' EndPoint Address
    Dt _cINT                                        ' Attributes
    Dt Low(cHID_INT_IN_EP_SIZE), High(cHID_INT_IN_EP_SIZE)  ' Size of the EndPoint buffer (in bytes) (low byte,high byte)
    Dt cUSB_POLLING_INTERVAL                        ' Polling interval (in ms)
Desc_EndConfig1:

Desc_ReportDescriptor1:
    Dt 0x05, 0x01       ' Usage page (generic desktop)
    Dt 0x09, 0x02       ' Usage (mouse)
    Dt 0xA1, 0x01       ' Collection (application)
    Dt 0x09, 0x01       '   Usage (pointer)
    Dt 0xA1, 0x00       '   Collection (linked)
    Dt 0x05, 0x09       '     Usage page (buttons)
    Dt 0x19, 0x01       '     Usage minimum (1)
    Dt 0x29, 0x03       '     Usage maximum (3)
    Dt 0x15, 0x00       '     Logical minimum (0)
    Dt 0x25, 0x01       '     Logical maximum (1)
    Dt 0x95, 0x03       '     Report count (3)
    Dt 0x75, 0x01       '     Report size (1)
    Dt 0x81, 0x02       '     Input (3 button bits)
    Dt 0x95, 0x01       '     Report count (1)
    Dt 0x75, 0x05       '     Report size (5)
    Dt 0x81, 0x01       '     Input (constant 5 bit padding)
    Dt 0x05, 0x01       '     Usage page (generic desktop)
    Dt 0x09, 0x30       '     Usage (X)
    Dt 0x09, 0x31       '     Usage (Y)
    Dt 0x15, 0x81       '     Logical minimum (-127)
    Dt 0x25, 0x7F       '     Logical maximum (127)
    Dt 0x75, 0x08       '     Report size (8)
    Dt 0x95, 0x02       '     Report count (2)
    Dt 0x81, 0x06       '     Input (2 position bytes X & Y)
    Dt 0xC0, 0xC0       ' End collection
Desc_EndReportDescriptor1:
'
' Configuration pointer table
Desc_USB_CD_Ptr:-
Desc_Configs:-
    CData As Dword Desc_Config1
'
' String pointer table
'
Desc_USB_SD_Ptr:-
Desc_Strings:-
    CData As Dword Desc_String0, Desc_String1, Desc_String2
'
' Language code string descriptor
'
Desc_String0:-
    dt (Desc_String1 - Desc_String0) / 2            ' Size of this descriptor (in bytes)
    dt cUSB_DESCRIPTOR_STRING                       ' String descriptor type
    dt 0x09, 0x04                                   ' Language ID as defined by MS - 0x0409
'
' Manufacturer string descriptor
'
Desc_String1:-
    dt (Desc_String2 - Desc_String1) / 2            ' Size of this descriptor (in bytes)
    dt cUSB_DESCRIPTOR_STRING                       ' String descriptor type
    CData As Dword "Microchip Technology Inc."
'
' Product string descriptor
'
Desc_String2:-
    dt (_DescriptorMain_ - Desc_String2) / 2  ' Size of this descriptor (in bytes)
    dt cUSB_DESCRIPTOR_STRING                       ' String descriptor type
    CData As Dword "Mouse In a circle Demo"

_DescriptorMain_:
$endif ' _MOUSE_DESC_INC_
